﻿Imports ThinkGeo.MapSuite.Core
Imports System.Collections.ObjectModel
Public Class DynamicSegmentationShapeFile
    Inherits ShapeFileFeatureLayer
    Public DynSegTable As DataTable
    Public Property AsphaltSym As LineStyle
    Public Property GravelSym As LineStyle
    Public Property ConcreteSym As LineStyle
    Public Sub New(sPath As String)
        MyBase.New(sPath)
    End Sub
    Protected Overrides Sub DrawCore(canvas As GeoCanvas, labelsInAllLayers As Collection(Of SimpleCandidate))
        'MyBase.DrawCore(canvas, labelsInAllLayers)

        Dim oRows() As DataRow
        Dim oFeatures As Collection(Of Feature) = QueryTools.GetAllFeatures(ReturningColumnsType.AllColumns)
        Dim dStartDistance As Double
        Dim dDistance As Double
        Dim oLineShape As MultilineShape
        Dim oTextStyle As New TextStyle("Type", New GeoFont("Arial", 10), New GeoSolidBrush(GeoColor.SimpleColors.Black))
        Dim oShapes As New Collection(Of BaseShape)

        With oTextStyle
            .DrawingLevel = DrawingLevel.LabelLevel
            .DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels
            .LabelAllLineParts = True
            .OverlappingRule = LabelOverlappingRule.AllowOverlapping
            .SplineType = SplineType.StandardSplining
            .TextLineSegmentRatio = 100
            .IsActive = True

        End With

        Dim oLabels As New Collection(Of SimpleCandidate)
        For Each oFeature In oFeatures
            oLineShape = CType(oFeature.GetShape, MultilineShape)
            oRows = DynSegTable.Select("FeatureID='" & oFeature.Id & "' AND Type='Line'", "DistanceFrom ASC")
            For Each oRow As DataRow In oRows
                dStartDistance = CType(oRow("DistanceFrom"), Double)
                dDistance = CType(oRow("DistanceTo"), Double) - dStartDistance

                Dim oSegmentLineShape As LineBaseShape = oLineShape.GetLineOnALine(
                                              StartingPoint.FirstPoint,
                                              dStartDistance,
                                              dDistance,
                                              GeographyUnit.Meter,
                                              DistanceUnit.Meter)
                oShapes.Clear()
                oShapes.Add(oSegmentLineShape)

                Dim typeName As String = "normal"
                Select Case oRow("Description").ToString
                    Case "Asphalt"
                        AsphaltSym.Draw(oShapes, canvas, labelsInAllLayers, labelsInAllLayers)
                        typeName = "Asphalt"
                    Case "Gravel"
                        GravelSym.Draw(oShapes, canvas, labelsInAllLayers, labelsInAllLayers)
                        typeName = "Gravel"
                    Case "Concrete"
                        ConcreteSym.Draw(oShapes, canvas, labelsInAllLayers, labelsInAllLayers)
                        typeName = "Concrete"
                End Select

                Dim newFeatures As New Collection(Of Feature)
                If oFeature.ColumnValues.ContainsKey("Type") Then
                    oFeature.ColumnValues("Type") = typeName
                Else
                    oFeature.ColumnValues.Add("Type", typeName)
                End If
                Dim newFeature As New Feature(oSegmentLineShape, oFeature.ColumnValues)
                newFeatures.Add(newFeature)

                oTextStyle.Draw(newFeatures, canvas, labelsInAllLayers, labelsInAllLayers)
            Next oRow

        Next oFeature

    End Sub

End Class
